@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "box_data_list.h"
@@ -379,12 +379,12 @@ Gnome::Gda::Value Box_Data_List::get_entered_field_data(const sharedptr<const La
 
 void Box_Data_List::set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
-  return m_AddDel.set_value_selected(field, value);
+  m_AddDel.set_value_selected(field, value);
 }
 
 void Box_Data_List::set_entered_field_data(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
-  return m_AddDel.set_value(row, field, value);
+  m_AddDel.set_value(row, field, value);
 }
 
 bool Box_Data_List::get_showing_multiple_records() const
