@@ -89,10 +89,10 @@ public:
 
   void add_layout_item(const sharedptr<LayoutItem>& item);
 
-  /**
+    /**
    * @param with_indent Pass true for top-level groups, to avoid wasting extra space with an unnecessary indent.
    */
-  void add_layout_group(const sharedptr<LayoutGroup>& group, bool with_indent = true);
+  void add_layout_group_or_derived(const sharedptr<LayoutGroup>& group, bool with_indent = true);
 
   void set_field_editable(const sharedptr<const LayoutItem_Field>& field, bool editable = true);
 
@@ -226,7 +226,7 @@ private:
 
     sharedptr<const LayoutItem_Field> m_field; //Store the field information so we know the title, ID, and type.
 
-    Gtk::Label* m_first;
+    Gtk::Widget* m_first;
     Gtk::EventBox* m_first_eventbox; //The label is often inside an eventbox.
     Glib::RefPtr<Gtk::SizeGroup> m_first_in_sizegroup; //Just to avoid a warning when removing a widget not in a group.
 
@@ -252,6 +252,14 @@ private:
   void add_imageobject(const sharedptr<LayoutItem_Image>& layoutitem_image, const Glib::ustring& table_name);
 
   void add_layoutwidgetbase(LayoutWidgetBase* layout_widget);
+
+  /** Add a normal group, not a notebook or portal.
+   * See also add_layout_group_or_derived().
+   *
+   * @param with_indent Pass true for top-level groups, to avoid wasting extra space with an unnecessary indent.
+   */
+  void add_layout_group(const sharedptr<LayoutGroup>& group, bool with_indent = true);
+
   void add_layout_notebook(const sharedptr<LayoutItem_Notebook>& notebook);
   void add_layout_portal(const sharedptr<LayoutItem_Portal>& portal);
 
