@@ -108,7 +108,7 @@ void UiUtils::show_help(Gtk::Window* parent_window, const Glib::ustring& id)
   }
   catch(const std::exception& ex)
   {
-    const auto message = Glib::ustring::compose(_("Could not display help: %1"), Glib::ustring(ex.what()));
+    const Glib::ustring message = Glib::ustring::compose(_("Could not display help: %1"), Glib::ustring(ex.what()));
     Gtk::MessageDialog dialog(message, false, Gtk::MESSAGE_ERROR);
     dialog.run();
   }
